<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */

if ( ! function_exists( 'yule_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Yule 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function yule_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'yule_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Check if popular section is enabled.
 *
 * @since Yule 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_is_popular_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_theme_options[popular_section_enable]' )->value() );
}

/**
 * Check if popular section content type  is page.
 *
 * @since Yule 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_is_popular_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'yule_theme_options[popular_content_type]' )->value();
	return yule_is_popular_section_enable( $control ) && ( 'page' === $content_type );
}

/**
 * Check if popular section content type  is product.
 *
 * @since Yule 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_is_popular_section_content_product_enable( $control ) {
	$content_type = $control->manager->get_setting( 'yule_theme_options[popular_content_type]' )->value();
	return yule_is_popular_section_enable( $control ) && ( 'product' === $content_type );
}

/**
 * Check if latest section is enabled.
 *
 * @since Yule 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_is_latest_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_theme_options[latest_section_enable]' )->value() );
}

/**
 * Check if call to action section is enabled.
 *
 * @since Yule 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function yule_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'yule_theme_options[cta_section_enable]' )->value() );
}