<?php
/**
 * Yule basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Yule
 * @since Yule 1.0.0
 */

$options = yule_get_theme_options();


if ( ! function_exists( 'yule_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Yule 1.0.0
	 */
	function yule_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'yule_doctype', 'yule_doctype', 10 );


if ( ! function_exists( 'yule_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'yule_before_wp_head', 'yule_head', 10 );

if ( ! function_exists( 'yule_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'yule' ); ?></a>

		<?php
	}
endif;

add_action( 'yule_page_start_action', 'yule_page_start', 10 );

if ( ! function_exists( 'yule_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'yule_page_end_action', 'yule_page_end', 10 );

if ( ! function_exists( 'yule_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_header_start() {
		?>
		<header id="masthead" class="site-header" role="banner">
            <div class="wrapper">
		<?php
	}
endif;
add_action( 'yule_header_action', 'yule_header_start', 10 );

if ( ! function_exists( 'yule_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_site_branding() {
		$options  = yule_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<div class="site-branding">
            <?php if ( 'show-all' === $header_txt_logo_extra || 'logo-title' === $header_txt_logo_extra || 'logo-tagline' === $header_txt_logo_extra ) { ?>
        		<div class="site-logo">
					<?php the_custom_logo(); ?>
        		</div><!-- .site-logo -->
			<?php } ?>

            <div id="site-details">
                <?php 
				 
				if( 'show-all' === $header_txt_logo_extra  || 'title-only' === $header_txt_logo_extra || 'logo-title' === $header_txt_logo_extra ) {
					if ( yule_is_latest_posts() ) : ?>
						<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
					<?php else : ?>
						<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
					<?php
					endif;
				} 
				if ( 'show-all' === $header_txt_logo_extra  || 'tagline-only' === $header_txt_logo_extra || 'logo-tagline' === $header_txt_logo_extra ) {
					$description = get_bloginfo( 'description', 'display' );
					if ( $description || is_customize_preview() ) : ?>
						<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
					<?php
					endif; 
				}?>
            </div><!-- #site-details -->
        </div><!-- .site-branding -->
		<?php
	}
endif;
add_action( 'yule_header_action', 'yule_site_branding', 20 );

if ( ! function_exists( 'yule_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_site_navigation() {
		?>
		<nav id="site-navigation" class="main-navigation" role="navigation">
			<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
				<?php
					echo yule_get_svg( array( 'icon' => 'menu' ) );
					echo yule_get_svg( array( 'icon' => 'close' ) );
				?>
			</button>
			<?php wp_nav_menu( array( 
				'fallback_cb'=>'yule_menu_fallback_cb', 
				'container' => 'div',
				'theme_location' => 'primary', 
				'menu_id' => 'primary-menu',
				'menu_class' => 'menu nav-menu'
			) ); ?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'yule_header_action', 'yule_site_navigation', 30 );


if ( ! function_exists( 'yule_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_header_end() {
		?>
			</div>
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'yule_header_action', 'yule_header_end', 50 );

if ( ! function_exists( 'yule_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'yule_content_start_action', 'yule_content_start', 10 );

if ( ! function_exists( 'yule_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_content_end() {
		?>
		<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'yule_content_end_action', 'yule_content_end', 10 );

if ( ! function_exists( 'yule_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'yule_footer', 'yule_footer_start', 10 );

if ( ! function_exists( 'yule_social_menu' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_social_menu() {
		if ( has_nav_menu( 'social' ) ) : ?>
			<div class="social-menu">
				<?php
					wp_nav_menu( array(
						'theme_location' => 'social',
						'menu_class'     => 'social-icons',
						'depth'          => 1,
						'link_before'    => '<span class="screen-reader-text">',
						'link_after'     => '</span>' . yule_get_svg( array( 'icon' => 'chain' ) ),
					) );
				?>
			</div>
		<?php endif;
	}
endif;
add_action( 'yule_footer', 'yule_social_menu', 40 );

if ( ! function_exists( 'yule_footer_site_info_start' ) ) :
	/**
	 * Site info starts
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_footer_site_info_start() {
		$class = 'col-1';
		if ( has_nav_menu( 'social' ) ) :
			$class = 'col-2';
		endif;
		?>
		<div class="site-info">
			<div class="wrapper <?php echo esc_attr( $class ); ?>">
				<div class="footer-copyright">
					<span>
					<?php esc_html_e( 'Proudly powered by ', 'yule' ); ?><a href="<?php echo esc_url( __( 'https://wordpress.org/', 'yule' ) ); ?>"><?php esc_html_e( 'WordPress', 'yule' ); ?></a>
					<span class="sep"> | </span>
					<?php printf( esc_html__( '%1$s by %2$s.', 'yule' ), 'Yule', '<a href="' . esc_url( __( 'https://themepalace.com/', 'yule' ) ) . '" rel="designer">Theme Palace</a>' );
					if ( function_exists( 'the_privacy_policy_link' ) ) {
						the_privacy_policy_link( '<span> | </span>' );
					}
					 ?>
					</span>
				</div>
		<?php
	}
endif;
add_action( 'yule_footer', 'yule_footer_site_info_start', 30 );

if ( ! function_exists( 'yule_footer_site_info_end' ) ) :
	/**
	 * Site info ends
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_footer_site_info_end() {
		?>
			</div><!--.wrapper-->
		</div><!--.site-info-->
		<?php
	}
endif;
add_action( 'yule_footer', 'yule_footer_site_info_end', 80 );

if ( ! function_exists( 'yule_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_footer_scroll_to_top() {
		$options  = yule_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo yule_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'yule_footer', 'yule_footer_scroll_to_top', 90 );

if ( ! function_exists( 'yule_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_footer_end() {
		?>
		</footer>
		<?php
	}
endif;
add_action( 'yule_footer', 'yule_footer_end', 100 );

if ( ! function_exists( 'yule_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Yule 1.0.0
	 *
	 */
	function yule_loader() {
		$options = yule_get_theme_options();
		if ( $options['loader_enable'] ) { ?>
			<div id="loader">
	            <div class="loader-container">
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            </div>
        	</div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'yule_before_header', 'yule_loader', 10 );